<?php

namespace App\Http\Controllers;

use App\Models\AdminCategory;
use App\Models\Comment;
use App\Models\PostCategory;
use App\Models\Ticket;
use App\Models\Unit;
use App\Models\User;
use GuzzleHttp\Client;
use Illuminate\Http\Request;

class AdminCategoryController extends Controller
{
    public function indexStaff() {
        $urlApi = config('api.api_url');

        $client = new Client([
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);
        
        $search = request('search');
        $categorySearch = request('category');
        $orderSearch = request('order_by');

        if($search) {            
            $responseTickets = $client->request('GET', $urlApi . 'tickets?search=' . $search);
        } else if($categorySearch) {
            $responseTickets = $client->request('GET', $urlApi . 'tickets?category=' . $categorySearch);
        } else if($orderSearch) {
            $responseTickets = $client->request('GET', $urlApi . 'tickets?order_by=' . $orderSearch);
        } else {
            $responseTickets = $client->request('GET', $urlApi . 'tickets');
        }
        
        $statusCodeTickets = $responseTickets->getStatusCode();
        
        $responseCategories = $client->request('GET', $urlApi . 'categories');
        $statusCodeCategories = $responseCategories->getStatusCode();

        if($statusCodeTickets == 200 && $statusCodeCategories == 200) {
            $tickets = json_decode($responseTickets->getBody());
            $post_categories = json_decode($responseCategories->getBody());

            return view('ticket.admin.index', [
                'title' => 'Tiket Aduan',
                'post_categories' => $post_categories->categories,
                'tickets' => $tickets->tickets
            ]);
        } else {
            return view('errors.500', [
                'message' => '500 Internal Server Error'
            ]);
        }
    }

    public function showStaff(Ticket $ticket) {
        $urlApi = config('api.api_url');

        $ticket_comments = Comment::latest()->where('ticket_id', $ticket->id)->whereNull('parent_id')->get();
        
        $client = new Client([
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);

        $responseTicket = $client->request('GET', $urlApi . 'tickets/' . $ticket->slug);
        $statusCode1 = $responseTicket->getStatusCode();

        if($statusCode1 == 200) {
            $ticket = json_decode($responseTicket->getBody());

            return view('ticket.admin.show', [
                'ticket' => $ticket->tickets,
                'ticket_comments' => $ticket_comments,
                'title' => 'Detail Tiket'
            ]);
        } else {
            return view('errors.500', [
                'message' => '500 Internal Server Error'
            ]);
        }
    }

    // SUPERADMIN
    public function index()
    {
        $urlApi = config('api.api_url');
        
        $client = new Client([
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);
        
        $response = $client->request('GET', $urlApi . 'staff-ahli');
            
        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            $users = json_decode($response->getBody());

            return view('users.superadmin.staffAhli.index', [
                'title' => 'Manajemen Staff Ahli',
                'users' => $users->users
            ]);
        } else {
            return view('errors.500', [
                'message' => '500 Internal Server Error'
            ]);
        }
    }
    
    public function create()
    {
        $urlApi = config('api.api_url');
        
        $client = new Client([
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);
        
        $response = $client->request('GET', $urlApi . 'staff-ahli/categories');
            
        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            $categories = json_decode($response->getBody());

            return view('users.superadmin.staffAhli.create', [
                'admin_categories' => $categories->categories,
                'title' => 'Tambah Staff Ahli'
            ]);
        } else {
            return view('errors.500', [
                'message' => '500 Internal Server Error'
            ]);
        }
    }

    public function store(Request $request)
    {
        $urlApi = config('api.api_url');

        $validatedData = $request->validate([
            'name' => 'required|max:255',
            'admin_category_id' => 'required',
            'email' => 'required|email:dns|unique:users',
            'password' => 'required|min:8',
        ]);

        $client = new Client();
    
        $response = $client->post($urlApi . 'staff-ahli', [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
            'json' => $validatedData
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            return redirect('/dashboard/staff-ahli')->with('toast_success', "User berhasil dibuat");
        } else {
            return redirect('/dashboard/staff-ahli')->with('toast_error', "User gagal dibuat");
        }
    }
    
    public function destroy($id)
    {
        $urlApi = config('api.api_url');

        $client = new Client();
    
        $response = $client->delete($urlApi . 'staff-ahli/' . $id, [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            return back()->with('toast_success', "User berhasil dihapus");
        } else {
            return back()->with('toast_error', "User gagal dihapus");
        }
    }
}