<?php

namespace App\Http\Controllers;

use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Session;
use Illuminate\Validation\ValidationException;

class AuthController extends Controller
{
    public function index() 
    {
        return view('auth.login', [
            'title' => 'Login'
        ]);
    }

    public function authenticate(Request $request) {
        $credentials = $request->validate([
            'email' => ['required', 'email'],
            'password' => ['required'],
            // 'captcha' => ['required', 'captcha'],
        ]);

        if (Auth::attempt($credentials)) {
            $user = User::where('email', $request->email)->first();

            $latestToken = $user->tokens()->latest()->first();

            if ($latestToken) {
                $latestToken->delete();
            }

            session()->forget('api_token');

            if(empty($token) || $user->tokenHasExpired()) {
                $token = $user->createToken('User Token')->plainTextToken;
                $request->session()->put('api_token', $token);
            }
            
            if ($user->role->name == 'user') {
                return redirect('/tickets');
            } else if ($user->role->name == 'admin') {
                return redirect('/dashboard');
            } else if ($user->role->name == 'admin-category') {
                return redirect('/dashboard/admin-category');
            } else {
                return redirect('/dashboard/superadmin');
            }
        } else {
            Session::flash('message', 'Username atau Password Salah!'); 
            return back();
        }
    }
    
    public function reloadCaptcha()
    {
        return response()->json(['captcha'=> captcha_img()]);
    }

    public function logout()
    {
        Auth::logout();
        return redirect('/');
    }
}