<?php

namespace App\Http\Controllers;

use App\Models\AdminCategory;
use App\Models\Post;
use App\Models\PostCategory;
use GuzzleHttp\Client;
use Illuminate\Http\Request;

class CategoryController extends Controller
{
    public function index()
    {
        $categories_count = PostCategory::all();

        $client = new Client([
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);

        $urlApi = config('api.api_url');

        $responseCategories = $client->request('GET', $urlApi . 'categories');
        $statusCode = $responseCategories->getStatusCode();

        if($statusCode == 200) {
            $post_categories = json_decode($responseCategories->getBody());

            return view('category.index', [
                'categories' => $post_categories->categories,
                'categories_count' => $categories_count,
                'title' => 'Kategori Diskusi'
            ]);
        } else {
            return view('errors.500', [
                'message' => '500 Internal Server Error'
            ]);
        }
    }

    public function store(Request $request)
    {
        $urlApi = config('api.api_url');

        $validatedData = $request->validate([
            'name' => 'required',
            'slug' => 'required',
        ]);

        $client = new Client();
    
        $response = $client->post($urlApi . 'categories', [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
            'json' => $validatedData
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            return back()->with('toast_success', "Kategori berhasil dibuat");
        } else {
            return back()->with('toast_error', "Kategori gagal dibuat");
        }
    }

    public function update(Request $request, PostCategory $category)
    {
        $validatedData = $request->validate([
            'name' => 'required',
            'slug' => 'required',
        ]);
        
        $urlApi = config('api.api_url');
 
        $client = new Client();

        $response = $client->patch($urlApi . 'categories/' . $category->slug, [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ], 
            'json' => $validatedData
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            return back()->with('toast_success', "Kategori berhasil diupdate");
        } else {
            return back()->with('toast_error', "Kategori gagal diupdate");
        }
    }

    public function toggleStatus(PostCategory $category) {
        $urlApi = config('api.api_url');
 
        $client = new Client();

        $response = $client->put($urlApi . 'categories/' . $category->slug . '/toggle', [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ], 
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            return back();
        } else {
            return back()->with('toast_error', "Kategori gagal diupdate");
        }       
    }
    
    public function destroy($id)
    {
        $urlApi = config('api.api_url');

        $client = new Client();
    
        $response = $client->delete($urlApi . 'categories/' . $id, [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            return back()->with('toast_success', "Kategori berhasil dihapus");
        } else {
            return back()->with('toast_error', "Kategori gagal dihapus");
        }
    }
}