<?php

namespace App\Http\Controllers;

use App\Models\Faq;
use GuzzleHttp\Client;
use Illuminate\Http\Request;

class FaqController extends Controller
{
    public function indexUser()
    {
        $urlApi = config('api.api_url');

        $client = new Client();
    
        $response = $client->get($urlApi . 'faq');

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            $body = $response->getBody();

            $faq = json_decode($body);
            
            return view('faq.user.index', [
                'faqs' => $faq->faq,
                'title' => 'FAQ'
            ]);
        } else {
            return view('errors.500', [
                'message' => '500 Internal Server Error'
            ]);
        }
    }
    
    public function index()
    {
        $urlApi = config('api.api_url');

        $client = new Client();
    
        $response = $client->get($urlApi . 'faq');

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            $faq = json_decode($response->getBody());

            return view('faq.superadmin.index', [
                'faqs' => $faq->faq,
                'title' => 'FAQ'
            ]);
        } else {
            return view('errors.500', [
                'message' => '500 Internal Server Error'
            ]);
        }
    }

    public function show(Faq $faq)
    {
        $urlApi = config('api.api_url');

        $client = new Client();
    
        $response = $client->get($urlApi . 'faq/' . $faq->slug, [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            $faq = json_decode($response->getBody());

            return view('faq.superadmin.show', [
                'faq' => $faq->faq,
                'title' => 'FAQ'
            ]);
        } else {
            return view('errors.500', [
                'message' => '500 Internal Server Error'
            ]);
        }
    }

    public function store(Request $request)
    {
        $validatedData = $request->validate([
            'title' => 'required',
            'answer' => 'required',
            'slug' => 'required',
        ]);
        
        $urlApi = config('api.api_url');
 
        $client = new Client();

        $response = $client->post($urlApi . 'faq', [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ], 
            'json' => $validatedData
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            return back()->with('toast_success', "FAQ berhasil ditambahkan!");
        } else {
            return back()->with('toast_error', "FAQ gagal ditambahkan!");
        }
    }
    
    public function edit(Faq $faq)
    {
        return view('faq.superadmin.edit', [
            'faq' => $faq,
            'title' => 'Edit Kategori',
        ]);
    }

    public function update(Request $request, Faq $faq)
    {
        $validatedData = $request->validate([
            'title' => 'required',
            'answer' => 'required',
            'slug' => 'required',
        ]);

        if($request->slug != $faq->slug) {
            $validatedData['slug'] = 'required';
        }
        
        $urlApi = config('api.api_url');
 
        $client = new Client();

        $response = $client->patch($urlApi . 'faq/' . $faq->slug, [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ], 
            'json' => $validatedData
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            return redirect('/dashboard/faq')->with('toast_success', "FAQ berhasil diupdate");
        } else {
            return redirect('/dashboard/faq')->with('toast_error', "FAQ gagal diupdate");
        }
    }
    
    public function destroy(Faq $faq)
    {        
        $urlApi = config('api.api_url');
 
        $client = new Client();

        $response = $client->delete($urlApi . 'faq/' . $faq->slug, [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ], 
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            return redirect('/dashboard/faq')->with('toast_success', "FAQ berhasil dihapus");
        } else {
            return redirect('/dashboard/faq')->with('toast_error', "FAQ gagal dihapus");
        }
    }
}