<?php

namespace App\Http\Controllers;

use App\Models\Unit;
use App\Models\User;
use GuzzleHttp\Client;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;

class StaffController extends Controller
{
    public function index()
    {
        $urlApi = config('api.api_url');

        $client = new Client();
    
        $response = $client->get($urlApi . 'staff', [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ]
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            $users = json_decode($response->getBody());

            // return response()->json($users);
            
            return view('users.superadmin.index', [
                'title' => 'Manajemen Staff Admin',
                'users'=> $users->users
            ]);
        } else {
            return view('errors.500', [
                'message' => '500 Internal Server Error'
            ]);
        }
    }
    
    public function create()
    {
        $urlApi = config('api.api_url');
        
        $client = new Client([
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);
        
        $response = $client->request('GET', $urlApi . 'units');
            
        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            $units = json_decode($response->getBody());

            return view('users.superadmin.create', [
                'title' => 'Tambah Staff',
                'units' => $units->units
            ]);
        } else {
            return view('errors.500', [
                'message' => '500 Internal Server Error'
            ]);
        }
       
    }

    public function store(Request $request)
    {
        $urlApi = config('api.api_url');

        $validatedData = $request->validate([
            'name' => 'required',
            'unit_id' => 'required',
            'email' => 'required|email:dns|unique:users',
            'password' => 'required|min:3',
        ]);

        $client = new Client();
    
        $response = $client->post($urlApi . 'staff', [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
            'json' => $validatedData
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            return redirect('/dashboard/staff')->with('toast_success', "Staff berhasil dibuat");
        } else {
            return redirect('/dashboard/staff')->with('toast_error', "Staff gagal dibuat");
        }
    }

    public function update(Request $request, User $user)
    {
        $urlApi = config('api.api_url');

        $validatedData = $request->validate([
            'nip' => 'required',
            'name' => 'required|max:255',
            'email' => [
                'required',
                'email:dns',
                Rule::unique('users')->ignore($user->id),
            ],
        ]);    

        $client = new Client();
    
        $response = $client->put($urlApi . 'staff/' . $user->id, [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
            'json' => $validatedData
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            return redirect('/dashboard/staff')->with('toast_success', "User berhasil diupdate");
        } else {
            return redirect('/dashboard/staff')->with('toast_error', "User gagal diupdate");
        }   
    }
    
    public function destroy($id)
    {
        $urlApi = config('api.api_url');

        $client = new Client();
    
        $response = $client->delete($urlApi . 'staff/' . $id, [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            return back()->with('toast_success', "Staff berhasil dihapus");
        } else {
            return back()->with('toast_error', "Staff gagal dihapus");
        }
    }
}