<?php

namespace App\Http\Controllers;

use App\Mail\MailNotify;
use App\Models\Comment;
use App\Models\PostCategory;
use App\Models\Ticket;
use App\Models\Unit;
use GuzzleHttp\Client;
use Illuminate\Http\Request;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class TicketController extends Controller
{
    public function index() {
        $urlApi = config('api.api_url');

        $client = new Client([
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);

        $search = request('search');
        $categorySearch = request('category');
        $orderSearch = request('order_by');

        if($search) {            
            $responseTickets = $client->request('GET', $urlApi . 'tickets?search=' . $search);
        } else if($categorySearch) {
            $responseTickets = $client->request('GET', $urlApi . 'tickets?category=' . $categorySearch);
        } else if($orderSearch) {
            $responseTickets = $client->request('GET', $urlApi . 'tickets?order_by=' . $orderSearch);
        } else {
            $responseTickets = $client->request('GET', $urlApi . 'tickets');
        }
        
        $statusCodeTickets = $responseTickets->getStatusCode();
        
        $responseCategories = $client->request('GET', $urlApi . 'categories');
        $statusCodeCategories = $responseCategories->getStatusCode();
        
        if($statusCodeTickets == 200 && $statusCodeCategories == 200) {

            $tickets = json_decode($responseTickets->getBody());

            // return response()->json($tickets);
            
            $post_categories = json_decode($responseCategories->getBody());

            return view('ticket.user.index', [
                'title' => 'Tiket Aduan',
                'post_categories' => $post_categories->categories,
                'tickets' => $tickets->tickets
            ]);
        } else {
            return view('errors.500', [
                'message' => '500 Internal Server Error'
            ]);
        }
    }

    public function show(Ticket $ticket)
    {   
        $urlApi = config('api.api_url');

        $ticket_comments = Comment::latest()->where('ticket_id', $ticket->id)->whereNull('parent_id')->get();
        
        $client = new Client([
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);

        $responseTicket = $client->request('GET', $urlApi . 'tickets/' . $ticket->slug);
        $statusCode1 = $responseTicket->getStatusCode();

        if($statusCode1 == 200) {
            $ticket = json_decode($responseTicket->getBody());

            return view('ticket.user.show', [
                'ticket' => $ticket->tickets,
                'ticket_comments' => $ticket_comments,
                'title' => 'Detail Tiket'
            ]);
        } else {
            return view('errors.500', [
                'message' => '500 Internal Server Error'
            ]);
        }
    }

    public function store(Request $request) 
    {
        $urlApi = config('api.api_url');

        $validatedData = $request->validate([
            'title' => 'required|max:255',
            'slug' => 'required',
            'category_id' => 'required',
            'body' => 'required',
            'attachment' => 'image|mimes:jpeg,png,jpg|max:10000',
        ]);

        if($request->file('attachment')) {
            $image = $request->file('attachment');
            $folder = 'ticket-img';
    
            $new_image_name = Str::uuid();
            $extension = $image->getClientOriginalExtension();
    
            $image->move($folder, $new_image_name . "." . $extension);
            $filename = $new_image_name . "." . $extension;
    
            $validatedData['attachment'] = $filename;
        }

        $client = new Client();
    
        $response = $client->post($urlApi . 'tickets', [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
            'json' => $validatedData
        ]);

        
        $statusCode = $response->getStatusCode();

        $ticket = json_decode($response->getBody());

        Mail::to(auth()->user()->email)->send(new MailNotify($ticket->ticket));

        if($statusCode == 200) {
            return back()->with('toast_success', "Ticket berhasil dibuat");
        } else {
            return back()->with('toast_error', "Ticket gagal dibuat");
        }
    }

    public function update(Ticket $ticket)
    {
        $urlApi = config('api.api_url');

        $isOwner = $ticket->user_id == auth()->user()->id;
        $isAdmin = $ticket->unit_id == auth()->user()->unit_id && auth()->user()->role_id == 2;
        $isSuperAdmin = auth()->user()->role_id == 1 || auth()->user()->role_id == 4;

        if($isOwner || $isAdmin || $isSuperAdmin) {
            $client = new Client();
    
            $response = $client->patch($urlApi . 'tickets/' . $ticket->slug, [
                'headers' => [
                    'Authorization' => 'Bearer ' . session('api_token'),
                    'Accept' => 'application/json',
                ]
            ]);
    
            $statusCode = $response->getStatusCode();

            if($statusCode == 200) {
                return back()->with('toast_success', "Ticket berhasil diselesaikan");
            } else {
                return back()->with('toast_error', "Ticket gagal diselesaikan");
            }
        } 

        return back()->with('toast_error', "Anda bukan pemilik tiket!");
    }

    public function indexAdmin() 
    {
        $urlApi = config('api.api_url');

        $client = new Client([
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);
        
        $search = request('search');
        $categorySearch = request('category');
        $orderSearch = request('order_by');

        if($search) {            
            $responseTickets = $client->request('GET', $urlApi . 'tickets?search=' . $search);
        } else if($categorySearch) {
            $responseTickets = $client->request('GET', $urlApi . 'tickets?category=' . $categorySearch);
        } else if($orderSearch) {
            $responseTickets = $client->request('GET', $urlApi . 'tickets?order_by=' . $orderSearch);
        } else {
            $responseTickets = $client->request('GET', $urlApi . 'tickets');
        }
        
        $statusCodeTickets = $responseTickets->getStatusCode();
        
        $responseCategories = $client->request('GET', $urlApi . 'categories');
        $statusCodeCategories = $responseCategories->getStatusCode();

        if($statusCodeTickets == 200 && $statusCodeCategories == 200) {
            $tickets = json_decode($responseTickets->getBody());
            $post_categories = json_decode($responseCategories->getBody());

            return view('ticket.admin.index', [
                'title' => 'Tiket Aduan',
                'post_categories' => $post_categories->categories,
                'tickets' => $tickets->tickets
            ]);
        } else {
            return view('errors.500', [
                'message' => '500 Internal Server Error'
            ]);
        }
    }

    public function showTicketAdmin(Ticket $ticket) {
        $urlApi = config('api.api_url');

        $ticket_comments = Comment::latest()->where('ticket_id', $ticket->id)->whereNull('parent_id')->get();
        
        $client = new Client([
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);

        $responseTicket = $client->request('GET', $urlApi . 'tickets/' . $ticket->slug);
        $statusCode1 = $responseTicket->getStatusCode();

        if($statusCode1 == 200) {
            $ticket = json_decode($responseTicket->getBody());

            return view('ticket.admin.show', [
                'ticket' => $ticket->tickets,
                'ticket_comments' => $ticket_comments,
                'title' => 'Detail Tiket'
            ]);
        } else {
            return view('errors.500', [
                'message' => '500 Internal Server Error'
            ]);
        }
    }

    public function indexSuperadmin() {
        return view('ticket.superadmin.home', [
            'tickets' => Ticket::all(),
            'units' => Unit::all(),
            'title' => 'Daftar Ticket'
        ]);
    }
    
    public function ticketsSuperadmin(Unit $unit) {
        $urlApi = config('api.api_url');

        $client = new Client([
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);
        
        $search = request('search');
        $categorySearch = request('category');
        $orderSearch = request('order_by');

        if($search) {            
            $responseTickets = $client->request('GET', $urlApi . 'tickets?search=' . $search);
        } else if($categorySearch) {
            $responseTickets = $client->request('GET', $urlApi . 'tickets?category=' . $categorySearch);
        } else if($orderSearch) {
            $responseTickets = $client->request('GET', $urlApi . 'tickets?order_by=' . $orderSearch);
        } else {
            $responseTickets = $client->request('GET', $urlApi . 'tickets');
        }
        
        $statusCodeTickets = $responseTickets->getStatusCode();
        
        $responseCategories = $client->request('GET', $urlApi . 'categories');
        $statusCodeCategories = $responseCategories->getStatusCode();

        if($statusCodeTickets == 200 && $statusCodeCategories == 200) {
            $tickets = json_decode($responseTickets->getBody());
            $post_categories = json_decode($responseCategories->getBody());

            return view('ticket.admin.index', [
                'title' => 'Tiket Aduan',
                'post_categories' => $post_categories->categories,
                'tickets' => $tickets->tickets
            ]);
        } else {
            return view('errors.500', [
                'message' => '500 Internal Server Error'
            ]);
        }
    }

    public function showtTicketsSuperadmin(Ticket $ticket) {
        $urlApi = config('api.api_url');

        $ticket_comments = Comment::latest()->where('ticket_id', $ticket->id)->whereNull('parent_id')->get();
        
        $client = new Client([
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);

        $responseTicket = $client->request('GET', $urlApi . 'tickets/' . $ticket->slug);
        $statusCode1 = $responseTicket->getStatusCode();

        if($statusCode1 == 200) {
            $ticket = json_decode($responseTicket->getBody());

            return view('ticket.admin.show', [
                'ticket' => $ticket->tickets,
                'ticket_comments' => $ticket_comments,
                'title' => 'Detail Tiket'
            ]);
        } else {
            return view('errors.500', [
                'message' => '500 Internal Server Error'
            ]);
        }
    }
}