<?php

namespace App\Http\Controllers;

use App\Models\Post;
use App\Models\PostCategory;
use App\Models\Topic;
use Illuminate\Http\Request;
use \Cviebrock\EloquentSluggable\Services\SlugService;
use GuzzleHttp\Client;

class TopicController extends Controller
{
    public function index()
    {
        $urlApi = config('api.api_url');

        $client = new Client([
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);

        $responseTopics = $client->request('GET', $urlApi . 'topics');
        $statusCode = $responseTopics->getStatusCode();


        if($statusCode == 200) {
            $topics = json_decode($responseTopics->getBody());
    
            return view('topic.index', [
                'title' => 'Topik Diskusi',
                'topics' => $topics->topics
            ]);
        } else {
            return view('errors.500', [
                'message' => '500 Internal Server Error'
            ]);
        }
    }

    public function store(Request $request)
    {
        $urlApi = config('api.api_url');

        $validatedData = $request->validate([
            'title' => 'required',
            'slug' => 'required',
        ]);

        $client = new Client();
    
        $response = $client->post($urlApi . 'topics', [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
            'json' => $validatedData
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            return back()->with('toast_success', "Topik berhasil dibuat");
        } else {
            return back()->with('toast_error', "Topik gagal dibuat");
        }
    }

    public function update(Request $request, Topic $topic)
    {   
        $validatedData = $request->validate([
            'title' => 'required',
            'slug' => 'required',
        ]);
        
        $urlApi = config('api.api_url');
 
        $client = new Client();

        $response = $client->patch($urlApi . 'topics/' . $topic->slug, [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ], 
            'json' => $validatedData
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            return back()->with('toast_success', "Topik berhasil diupdate");
        } else {
            return back()->with('toast_error', "Topik gagal diupdate");
        }
    }

    public function toggleStatus(Topic $topic) {        
        $urlApi = config('api.api_url');
 
        $client = new Client();

        $response = $client->put($urlApi . 'topics/' . $topic->slug . '/toggle', [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ], 
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            return back();
        } else {
            return back()->with('toast_error', "Topik gagal diupdate");
        }       
    }
    
    public function destroy($id)
    {
        $urlApi = config('api.api_url');

        $client = new Client();
    
        $response = $client->delete($urlApi . 'topics/' . $id, [
            'headers' => [
                'Authorization' => 'Bearer ' . session('api_token'),
                'Accept' => 'application/json',
            ],
        ]);

        $statusCode = $response->getStatusCode();

        if($statusCode == 200) {
            return back()->with('toast_success', "Topik berhasil dihapus");
        } else {
            return back()->with('toast_error', "Topik gagal dihapus");
        }
    }

    public function checkSlug(Request $request)
    {
        $slug = SlugService::createSlug(Topic::class, 'slug', $request->title);

        return response()->json(['slug' => $slug]);
    }
}