<?php

namespace App\Http\Controllers;

use App\Models\Faq;
use App\Models\Post;
use App\Models\PostCategory;
use App\Models\Ticket;
use App\Models\Topic;
use App\Models\Unit;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\DB;

class ViewController extends Controller
{
    public function chartData()
    {
        $startDate = Carbon::now()->subDays(6)->startOfDay();
        $endDate = Carbon::now()->endOfDay();

        $postHistory = Post::whereBetween('created_at', [$startDate, $endDate])
            ->groupBy('date')
            ->orderBy('date')
            ->get([
                DB::raw('DATE(created_at) as date'),
                DB::raw('COUNT(*) as count')
            ]);

        $ticketHistory = Ticket::whereBetween('created_at', [$startDate, $endDate])
            ->groupBy('date')
            ->orderBy('date')
            ->get([
                DB::raw('DATE(created_at) as date'),
                DB::raw('COUNT(*) as count')
            ]);
            
        if(auth()->user()->role_id == 2) {
            $postHistory = Post::whereBetween('created_at', [$startDate, $endDate])
            ->unit()
            ->groupBy('date')
            ->orderBy('date')
            ->get([
                DB::raw('DATE(created_at) as date'),
                DB::raw('COUNT(*) as count')
            ]);

            $ticketHistory = Ticket::whereBetween('created_at', [$startDate, $endDate])
                ->unit()
                ->groupBy('date')
                ->orderBy('date')
                ->get([
                    DB::raw('DATE(created_at) as date'),
                    DB::raw('COUNT(*) as count')
            ]);
        }
        
        $labels = [];
        $postCounts = [];
        $ticketCounts = [];

        $currentDate = $startDate;
        while ($currentDate <= $endDate) {
            $formattedDate = $currentDate->format('Y-m-d');
            $labels[] = $formattedDate;

            $postCount = $postHistory->firstWhere('date', $formattedDate);
            $postCounts[] = $postCount ? $postCount->count : 0;

            $ticketCount = $ticketHistory->firstWhere('date', $formattedDate);
            $ticketCounts[] = $ticketCount ? $ticketCount->count : 0;

            $currentDate->addDay();
        }

        $data = [
            'labels' => $labels,
            'postCounts' => $postCounts,
            'ticketCounts' => $ticketCounts
        ];

        return response()->json($data);
    }

    public function chartView()
    {
        return view('dashboard.admin.chart');
    }

    public function landingPage()
    {
        return view('index', [
            'posts' => Post::all(),
            'tickets' => Ticket::all(),
            'faqs' => Faq::all(),
            'topics' => Topic::all(),
            'finished' => Ticket::finished()->count(),
            'title' => 'Service Desk'
        ]);
    }

    public function dashboardAdmin()
    {
        $ticketsCount = Ticket::latest()->unit()->get();
        $postsCount = Post::latest()->unit()->count();
        $topicsCount = Topic::latest()->unit()->count();
        $usersCount = User::latest()->unit()->count();

        return view('dashboard.admin.index', [
            'title' => 'Dashboard Admin',
            'tickets' => $ticketsCount,
            'posts' => $postsCount,
            'topics' => $topicsCount,
            'users' => $usersCount,
        ]);
    }

    public function dashboardSuperAdmin()
    {
        $unitCount = Unit::all()->count();
        $post = Post::all()->count();
        $staffCount = User::where('role_id', 2)->count();

        return view('dashboard.superadmin.index', [
            'tickets' => Ticket::latest()->get(),
            'unit' => $unitCount,
            'post' => $post,
            'staff' => $staffCount,
            'title' => 'Dashboard Super Admin'
        ]);
    }
}