@extends('layouts.dashboard')

@section('container')
    <div class="p-4 sm:ml-64">
        <div class="mt-14">
            <div class="grid grid-cols-12 gap-4 mb-4">
                {{-- STATISTICS --}}
                <div class="col-span-12 flex flex-wrap space-y-2 lg:space-y-0 justify-between">
                    <a class="w-full inline-block lg:w-[calc(98%/4)] overflow-hidden p-4 bg-white border border-gray-200 rounded-lg shadow hover:bg-gray-100"
                        href="dashboard/tickets">
                        <div class="flex justify-between">
                            <div class="flex gap-2 items-center">

                                <div class="w-10 h-10 bg-orange-100 flex-center rounded-full">
                                    <i class="fa-solid fa-ticket text-orange-500"></i>
                                </div>
                                <p class="text-gray-800">Tiket Aduan</p>
                            </div>
                        </div>
                        <p class="font-bold text-5xl mt-4 text-gray-800">{{ $tickets->count() }}</p>
                        <p class="text-sm text-gray-400 mt-2">Tiket diterima</p>
                    </a>
                    <a class="w-full inline-block lg:w-[calc(98%/4)] overflow-hidden p-4 bg-white border border-gray-200 rounded-lg shadow hover:bg-gray-100"
                        href="dashboard/forum">
                        <div class="flex justify-between">
                            <div class="flex gap-2 items-center">

                                <div class="w-10 h-10 bg-purple-100 flex-center rounded-full">
                                    <i class="fa-sharp fa-solid fa-comments text-purple-700"></i>
                                </div>
                                <p class="text-gray-800">Forum Diskusi</p>
                            </div>
                        </div>
                        <p class="font-bold text-5xl mt-4 text-gray-800">{{ $posts }}</p>
                        <p class="text-sm text-gray-400 mt-2">Diskusi tersedia</p>
                    </a>
                    <a class="w-full inline-block lg:w-[calc(98%/4)] overflow-hidden p-4 bg-white border border-gray-200 rounded-lg shadow hover:bg-gray-100"
                        href="dashboard/topics">
                        <div class="flex justify-between">
                            <div class="flex gap-2 items-center">
                                <div class="w-10 h-10 bg-green-100 flex-center rounded-full">
                                    <i class="fa-solid fa-building text-green-700"></i>
                                </div>
                                <p class="text-gray-800">Topik Diskusi</p>
                            </div>
                        </div>
                        <p class="font-bold text-5xl mt-4 text-gray-800">{{ $topics }}</p>
                        <p class="text-sm text-gray-400 mt-2">Topik tersedia</p>
                    </a>
                    <a class="w-full inline-block lg:w-[calc(98%/4)] overflow-hidden p-4 bg-white border border-gray-200 rounded-lg shadow hover:bg-gray-100"
                        href="dashboard/users">
                        <div class="flex justify-between">
                            <div class="flex gap-2 items-center">
                                <div class="w-10 h-10 bg-blue-100 flex-center rounded-full">
                                    <i class="fa-solid fa-users text-blue-700"></i>
                                </div>
                                <p class="text-gray-800">User</p>
                            </div>
                        </div>
                        <p class="font-bold text-5xl mt-4 text-gray-800">{{ $users }}</p>
                        <p class="text-sm text-gray-400 mt-2">Pengguna terdaftar</p>
                    </a>
                </div>
                {{-- END STATISTICS --}}

                <div class="col-span-12 lg:col-span-8 ">
                    <div class="max-h-96 flex flex-col w-full px-4 py-6 pb-24 bg-white rounded-lg shadow">
                        <h2 class="text-xl font-bold">Grafik Tiket Aduan dan Forum Diskusi</h2>
                        <span class="text-sm text-gray-500 mb-6">*7 hari terakhir</span>

                        <canvas id="historyChart"></canvas>
                    </div>
                </div>

                <div class="col-span-12 lg:col-span-4">
                    <div class="flex flex-col px-4 py-6 pb-6 bg-white rounded-lg shadow">
                        <div class="flex justify-between items-center mb-4">
                            <h2 class="text-xl font-bold">Aduan masuk</h2>

                            <a href="/dashboard/tickets" class="w-10 h-10 bg-orange-100 flex-center rounded-full">
                                <i class="fa-solid fa-arrow-right text-orange-500"></i>
                            </a>
                        </div>
                        <div class="h-96 overflow-y-auto">
                            <div class="flex flex-col gap-2">
                                @if ($tickets->count())
                                    @foreach ($tickets as $ticket)
                                        <a href="{{ auth()->user()->role_id === 1 ? '/dashboard/superadmin/tickets/show/' . $ticket->slug : Request::url() . '/' . $ticket->slug }}"
                                            class="w-full inline-block {{ Request::is('tickets') ? 'lg:w-[calc(99%/3)]' : '' }} overflow-hidden p-6 bg-white border border-gray-200 rounded-lg shadow hover:bg-gray-100 ">

                                            <div class="header flex gap-2 align-middle justify-between">
                                                <div class="flex gap-4 mb-2">
                                                    <div>
                                                        <div>
                                                            <p class="font-bold text-blue-700">#{{ $ticket->id }}</p>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="flex items-center gap-2 h-fit">
                                                    <p class="text-gray-500 text-sm">
                                                        {{ $ticket->created_at->format('d M Y') }}
                                                        |
                                                        {{ $ticket->created_at->format('H:i') }}
                                                    </p>
                                                </div>
                                            </div>
                                            <p class="mb-2 text-xl font-bold tracking-tight text-gray-900">
                                                {{ Str::limit($ticket->title, '30') }}
                                            </p>
                                            <p class="text-gray-500 text-sm">
                                                Pengirim: {{ $ticket->user->name }}
                                            </p>
                                        </a>
                                    @endforeach
                                @else
                                    <p class="text-center fs-4 mt-5">Belum ada diskusi.</p>
                                @endif
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="{{ url('js/chart.js') }}"></script>
@endsection
