@extends('layouts.dashboard')

@section('container')
    <div class="p-4 sm:ml-64">
        <div class="mt-16">
            <div class="grid grid-cols-12 gap-4">
                <div class="col-span-12 lg:col-span-8">

                    <h2 class="mb-7 text-3xl font-bold leading-none tracking-tight text-gray-900 md:text-4xl">
                        Frequently Asked Question
                    </h2>

                    <div class="h-fit flex gap-4 justify-between align-middle">
                        <!-- CTA -->
                        <button data-modal-target="authentication-modal" data-modal-toggle="authentication-modal"
                            class="block text-white bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm h-auto px-4 py-2 text-center"
                            type="button">
                            Buat FAQ baru
                        </button>
                        <!-- END CTA -->
                    </div>
                    <!-- FAQ -->

                    <div class="faq mt-8 flex flex-col gap-4">

                        @foreach ($faqs as $faq)
                            <a href="/dashboard/faq/{{ $faq->slug }}"
                                class="block p-6 bg-white border border-gray-200 rounded-lg shadow hover:bg-gray-100">
                                <h5 class="mb-2 text-2xl font-bold tracking-tight text-gray-900">
                                    {{ $faq->title }}
                                </h5>
                                <p class="font-normal text-gray-700">
                                    {!! Str::limit($faq->answer, 80, '...') !!}
                                </p>
                            </a>
                        @endforeach
                    </div>

                    <!-- END FAQ -->

                </div>
                <div class="hidden lg:flex col-span-4 items-center justify-center rounded bg-transparent">
                </div>
            </div>
        </div>
    </div>

    <!-- Main modal -->
    <div id="authentication-modal" tabindex="-1" aria-hidden="true"
        class="fixed top-0 left-0 right-0 z-50 hidden w-full p-4 overflow-x-hidden overflow-y-auto md:inset-0 h-[calc(100%-1rem)] md:h-full"
        style="background: rgba(0, 0, 0, 0.5);">
        <div class="relative w-full h-full max-w-md md:h-auto">
            <!-- Modal content -->
            <div class="relative bg-white rounded-lg shadow">
                <button type="button"
                    class="absolute top-3 right-2.5 text-gray-400 bg-transparent hover:bg-gray-200 hover:text-gray-900 rounded-lg text-sm p-1.5 ml-auto inline-flex items-center"
                    data-modal-hide="authentication-modal">
                    <svg aria-hidden="true" class="w-5 h-5" fill="currentColor" viewBox="0 0 20 20"
                        xmlns="http://www.w3.org/2000/svg">
                        <path fill-rule="evenodd"
                            d="M4.293 4.293a1 1 0 011.414 0L10 8.586l4.293-4.293a1 1 0 111.414 1.414L11.414 10l4.293 4.293a1 1 0 01-1.414 1.414L10 11.414l-4.293 4.293a1 1 0 01-1.414-1.414L8.586 10 4.293 5.707a1 1 0 010-1.414z"
                            clip-rule="evenodd"></path>
                    </svg>
                    <span class="sr-only">Close modal</span>
                </button>

                <div class="px-6 py-6 lg:px-8">
                    <h3 class="mb-4 text-xl font-medium text-gray-900">Buat FAQ Baru</h3>
                    <form action="{{ url('/dashboard/faq') }}" method="POST">
                        @csrf
                        <div class="form-group mb-6">
                            <label for="helper-text" class="label">Pertanyaan</label>
                            <input type="text" id="title" aria-describedby="helper-text-explanation" name="title"
                                class="input-main" placeholder="Question" value="{{ old('title') }}" />
                        </div>

                        @error('title')
                            <div class="alert-danger" role="alert">
                                {{ $message }}
                            </div>
                        @enderror

                        <div class="form-group mb-6">

                            <label for="message" class="block mb-2 text-sm font-medium text-gray-900">Jawaban</label>
                            <textarea id="message" rows="4" name="answer" {{ old('answer') }}
                                class="block p-2.5 w-full text-sm text-gray-900 bg-gray-50 rounded-lg border border-gray-300 focus:ring-blue-500 focus:border-blue-500"
                                placeholder="Write the answer here..."></textarea>

                        </div>

                        @error('answer')
                            <div class="alert-danger" role="alert">
                                {{ $message }}
                            </div>
                        @enderror

                        <input type="text" class="" id="slug" name="slug" required
                            value="{{ old('slug') }}" hidden>


                        <div class="w-full flex justify-end mt-6">
                            <button type="submit"
                                class="text-white bg-blue-800 hover:bg-blue-800 focus:ring-4 focus:ring-blue-300 font-medium rounded-lg text-sm px-5 py-2.5">
                                Tambah
                            </button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>

    <script src="{{ url('js/slug.js') }}"></script>
@endsection
