@extends('layouts.main')

@section('container')
    <main class="w-11/12 m-auto lg:w-3/5 md:m-auto px-2">
        <div class="mt-10 grid grid-cols-12 gap-4">
            <!-- MAIN CONTENT -->
            <div class="col-span-12">
                <!-- POST -->
                <div class="border rounded-md p-6 bg-white">
                    <div class="header flex flex-col md:flex-row gap-2 align-middle justify-between mb-5">
                        <div class="flex gap-4 mb-6">
                            <div>
                                <p class="text-sm font-semibold h-fit text-secondary-700">
                                    {{ $post->user->name }}
                                </p>
                                <p class="font-normal text-xs text-secondary-400">
                                    {{ $post->created_at }}
                                </p>
                            </div>
                        </div>

                        @if (auth()->user()->id == $post->user->id)
                            @if ($post->is_finished == 0)
                                <form action="/forum/{{ $post->slug }}" method="POST">
                                    @csrf
                                    @method('PUT')
                                    <input type="hidden" name="id" value="{{ $post->id }}">
                                    <input type="hidden" name="is_finished" value="{{ $post->is_finished }}">
                                    <button data-modal-target="popup-modal" data-modal-toggle="popup-modal"
                                        class="h-fit w-full md:w-fit text-red-700 bg-red-50 border border-red-300 focus:outline-none hover:bg-red-100 focus:ring-4 focus:ring-red-200 font-medium rounded-lg text-sm px-5 py-2.5 mr-2 mb-2"
                                        type="button">
                                        Selesaikan diskusi
                                    </button>

                                    @include('layouts.components.modals.popup')
                                </form>
                            @else
                                <button type="button"
                                    class="h-fit text-green-700 bg-green-50 border border-green-300 focus:outline-none hover:bg-green-100 focus:ring-4 focus:ring-green-200 font-medium rounded-lg text-sm px-5 py-2.5 mr-2 mb-2">Diskusi
                                    Selesai</button>
                            @endif
                        @endif
                    </div>
                    <div>
                        <p class="text-2xl font-semibold mb-4">
                            {{ $post->title }}
                        </p>
                        <p class="font-light text-gray-500">
                            {!! $post->body !!}
                        </p>
                        @if ($post->attachment)
                            <div
                                class="w-full bg-gray-200 p-4 flex place-content-center rounded-lg mt-8 relative overflow-hidden">
                                <div class="hidden hover:flex w-full h-full absolute z-10 top-0 left-0 items-center justify-center "
                                    style="background: rgba(0, 0, 0, 0.5);">

                                    <button data-modal-target="image-modal" data-modal-toggle="image-modal"
                                        class="btn-link bg-gray-800 mb-4" type="button">
                                        Lihat gambar penuh
                                    </button>
                                </div>
                                <img class="w-11/12" src="{{ asset('storage/' . $post->attachment) }}" alt="">
                            </div>
                        @endif
                    </div>

                    <div class="flex flex-col md:flex-row mt-6 gap-4 justify-between md:items-center">
                        <div class="flex gap-2 mt-6">
                            <span
                                class="flex items-center text-xs font-normal bg-orange-500 text-white px-3 py-1 rounded-lg">{{ $post->category->name }}</span>
                            <span
                                class="flex items-center text-xs font-normal bg-purple-600 text-white px-3 py-1 rounded-lg">{{ $post->topic->title }}</span>
                        </div>


                        @if ($post->is_finished == 0)
                            <span
                                class="bg-red-100 text-red-800 text-xs md:text-sm font-medium px-3 py-2 md:py-1 text-center rounded h-fit">Diskusi
                                Belum
                                Selesai</span>
                        @else
                            <span
                                class="bg-green-100 text-green-800 text-xs md:text-sm font-medium px-3 py-2 md:py-1 text-center rounded h-fit">
                                Diskusi Selesai</span>
                        @endif

                    </div>
                    <!-- END POST -->
                </div>

                <!-- COMMENT -->

                <!-- COMMENT INPUT -->
                @include('layouts.components.comments.forum.input')
                <!-- END COMMENT INPUT -->

                @if ($post_comments->count())
                    @include('layouts.components.comments.forum.comment')
                @else
                    <div class="flex place-content-center py-10">
                        <p class="text-gray-600">Belum ada komentar</p>
                    </div>
                @endif

                <!-- END COMMENT -->
            </div>
            <!-- END MAIN CONTENT -->
        </div>
        {{-- @include('forum.partials.imageModal') --}}

    </main>
    <div class="mb-96"></div>
@endsection
