@extends('layouts.dashboard')

@section('container')
    <div class="p-4 sm:ml-64">
        <div class="mt-16">
            <div class="grid grid-cols-12 gap-4">
                <div class="col-span-12 lg:col-span-8">

                    @include('layouts.components.breadcumb')

                    <h2 class="mb-7 text-3xl font-bold leading-none tracking-tight text-gray-900 md:text-4xl">
                        Manajemen Topik
                    </h2>

                    <div class="bg-white relative shadow-md sm:rounded-lg overflow-hidden">
                        <div
                            class="flex flex-col md:flex-row items-center justify-between space-y-3 md:space-y-0 md:space-x-4 p-4">
                            <div class="w-full md:w-1/2">
                                <p class="font-semibold text-gray-400">Tabel Data Topik</p>
                            </div>
                            <div
                                class="w-full md:w-auto flex flex-col md:flex-row space-y-2 md:space-y-0 items-stretch md:items-center justify-end md:space-x-3 flex-shrink-0">
                                <button data-modal-target="topic-modal" data-modal-toggle="topic-modal"
                                    class="block text-white bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm px-5 py-2.5 h-fit text-center"
                                    type="button">
                                    Tambah Topik
                                </button>
                            </div>
                        </div>
                        <div class="overflow-x-auto">
                            <table class="w-full text-sm text-left text-gray-500">
                                <thead class="text-xs text-gray-700 uppercase bg-gray-50">
                                    <tr>
                                        <th scope="col" class="px-4 py-3">Nama Topik</th>
                                        <th scope="col" class="px-4 py-3">Status</th>
                                        <th scope="col" class="px-4 py-3 text-center">Actions</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach ($topics as $topic)
                                        <tr class="border-b">
                                            <th scope="row"
                                                class="px-4 py-3 font-medium text-gray-900 whitespace-nowrap">
                                                <p id="titleText-{{ $topic->id }}">
                                                    {{ $topic->title }}
                                                </p>
                                                <div id="editForm-{{ $topic->id }}" class="hidden">
                                                    <form action="/dashboard/topics/{{ $topic->slug }}" method="POST">
                                                        @csrf
                                                        @method('PUT')
                                                        <div class="form-group mb-3">
                                                            <input type="text" id="editTitle-{{ $topic->id }}"
                                                                onchange="slugEdit({{ $topic->id }})"
                                                                aria-describedby="helper-text-explanation" name="title"
                                                                class="input-main w-full" placeholder="Masukkan judul topik"
                                                                value="{{ $topic->title }}" required />
                                                        </div>

                                                        @error('title')
                                                            <div class="alert-danger" role="alert">
                                                                {{ $message }}
                                                            </div>
                                                        @enderror

                                                        <input type="text" class=""
                                                            id="editSlug-{{ $topic->id }}" name="slug" required
                                                            value="{{ $topic->slug }}">

                                                        <button type="submit" class="btn-link w-full">
                                                            Simpan
                                                        </button>
                                                    </form>
                                                </div>
                                            </th>
                                            <td class="px-4 py-3">
                                                @if ($topic->is_active)
                                                    <form action="/dashboard/topics/{{ $topic->slug }}/toggle"
                                                        method="POST">
                                                        @csrf
                                                        @method('PUT')
                                                        <button type="submit" class="btn-link-green w-28">Aktif</button>
                                                    </form>
                                                @else
                                                    <form action="/dashboard/topics/{{ $topic->slug }}/toggle"
                                                        method="POST">
                                                        @csrf
                                                        @method('PUT')
                                                        <button type="submit" class="btn-link-red w-28">Nonaktif</button>
                                                    </form>
                                                @endif
                                            </td>
                                            <td class="px-4 py-3 flex items-center justify-center">
                                                <div id="editButton" onclick="toggleEditForm({{ $topic->id }})"
                                                    class="flex mr-2 gap-2 bg-yellow-400 items-center rounded-lg py-2 px-3 text-white cursor-pointer">
                                                    <i class="fa-solid fa-pen-to-square"></i>

                                                    <p>Edit</p>
                                                </div>

                                                <div class="py-1">
                                                    <form action="/dashboard/topics/{{ $topic->id }}" method="POST"
                                                        class="d-inline">
                                                        @method('DELETE')
                                                        @csrf
                                                        <button
                                                            class="flex gap-2 bg-red-600 items-center rounded-lg py-2 px-3 text-white cursor-pointer"
                                                            onclick="return confirm('Apakah anda yakin ingin menghapus topik?')">
                                                            <i class="fa-solid fa-trash"></i> Delete
                                                        </button>
                                                    </form>
                                                </div>
                                            </td>
                                        </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>
                        <nav class="flex flex-col md:flex-row justify-between items-start md:items-center space-y-3 md:space-y-0 p-4"
                            aria-label="Table navigation">
                            <span class="text-sm font-normal text-gray-500">
                                Total:
                                <span class="font-semibold text-gray-900">{{ count($topics) }}</span>
                            </span>
                        </nav>
                    </div>
                </div>
                <div class="flex col-span-4 items-end justify-center rounded bg-transparent h-96">
                </div>
            </div>
        </div>
    </div>

    @include('layouts.components.modals.topic.create')

    <script src="{{ url('js/slug.js') }}"></script>
    <script src="{{ url('js/editForm.js') }}"></script>
@endsection
