<?php

use App\Http\Controllers\AdminCategoryController;
use App\Http\Controllers\AuthController;
use App\Http\Controllers\CategoryController;
use App\Http\Controllers\CommentController;
use App\Http\Controllers\FaqController;
use App\Http\Controllers\PostController;
use App\Http\Controllers\SettingsController;
use App\Http\Controllers\StaffController;
use App\Http\Controllers\TicketController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\TopicController;
use App\Http\Controllers\ViewController;
use App\Models\AdminCategory;
use Illuminate\Support\Facades\Route;


// AUTH
Route::get('/login', [AuthController::class, 'index']);
Route::get('/reload-captcha', [AuthController::class, 'reloadCaptcha']);

Route::post('/login', [AuthController::class, 'authenticate']);

Route::post('/logout', [AuthController::class, 'logout']);

Route::get('/', [ViewController::class, 'landingPage'])->name('login');
Route::get('/faq', [FaqController::class, 'indexUser']);


Route::middleware(['auth'])->group(function () {
    Route::post('/tickets/comment', [CommentController::class, 'storeTicket']);

    Route::post('/posts/comment', [CommentController::class, 'storePost']);

    Route::get('/forum/create/checkSlug', [PostController::class, 'checkSlug']);

    Route::put('/tickets/{ticket:slug}', [TicketController::class, 'update']);
    
    Route::post('/tickets/create', [TicketController::class, 'store']);
});

Route::middleware(['user'])->group(function () {
    Route::get('/tickets', [TicketController::class, 'index']);
    Route::get('/tickets/{ticket:slug}', [TicketController::class, 'show']);
    
    Route::get('/mail', [TicketController::class, 'mail']);
    
    Route::get('/forum', [PostController::class, 'index']);
    Route::get('/forum/{post:slug}', [PostController::class, 'show']);
    Route::post('/forum/create', [PostController::class, 'store']);
    Route::put('/forum/{post:slug}', [PostController::class, 'update']);
    
    Route::get('/settings', [SettingsController::class, 'index']);
    Route::post('/settings/change-password', [SettingsController::class, 'changePassword']);
});

Route::get('/chart-data', [ViewController::class, 'chartData']);

// ! ADMIN
Route::prefix('dashboard')->middleware('admin')->group(function() {
    Route::get('/', [ViewController::class, 'dashboardAdmin']);
    Route::get('/chart', [ViewController::class, 'chartView']);

    Route::get('/forum', [PostController::class, 'indexAdmin']);
    Route::get('/forum/{post:slug}', [PostController::class, 'showAdmin']);
    
    // USER
    Route::resource('/users', UserController::class);
    Route::get('/users/generatePassword', [UserController::class, 'generatePassword']);
    
    // TOPIC
    Route::resource('/topics', TopicController::class);
    Route::put('/topics/{topic:slug}/toggle', [TopicController::class, 'toggleStatus']);
    
    // TICKETS
    Route::get('/tickets', [TicketController::class, 'indexAdmin']);
    Route::get('/tickets/{ticket:slug}', [TicketController::class, 'showTicketAdmin']);
});

// ADMIN CATEGORY
Route::prefix('dashboard')->middleware('admin-category')->group(function() {
    Route::get('/admin-category', [AdminCategoryController::class, 'indexStaff']);
    Route::get('/admin-category/{ticket:slug}', [AdminCategoryController::class, 'showStaff']);
});

// ? SUPERADMIN
Route::prefix('dashboard')->middleware('superadmin')->group(function() {
    Route::get('/superadmin', [ViewController::class, 'dashboardSuperAdmin']);

    // STAFF
    Route::resource('/staff', StaffController::class);
    
    // STAFF AHLI
    Route::resource('/staff-ahli', AdminCategoryController::class);

    // CATEGORY
    Route::resource('/categories', CategoryController::class);
    Route::put('/categories/{category:slug}/toggle', [CategoryController::class, 'toggleStatus']);

    // FAQ
    Route::resource('/faq', FaqController::class);

    // TICKETS
    Route::get('/superadmin/tickets', [TicketController::class, 'indexSuperadmin']);
    Route::get('/superadmin/tickets/{unit:slug}', [TicketController::class, 'ticketsSuperadmin']);
    Route::get('/superadmin/tickets/show/{ticket:slug}', [TicketController::class, 'showtTicketsSuperadmin']);
});